@@ -178,7 +178,7 @@ class EPMDataDayItem():
     
     def _to_json_(self) -> dict:
         json_obj = {}
-        for k, v in self.__dict__.items():
+        for k, v in dict(sorted(self.__dict__.items())):
             if not k.startswith("_"):
                 json_obj[k] = v
         return json_obj
@@ -393,7 +393,8 @@ class SolisEPM():
     uAc3: str
     uAc3Str: str
     userId: str
-    def __init__(self, parent: SolisCloud):
+    def __init__(self, __parent__: SolisCloud):
+        self.__parent__: SolisCloud = __parent__
         self.collectorId = ""
         self.collectorSn = ""
         self.ctRatio = 0.0
@@ -508,14 +509,12 @@ class SolisEPM():
     def _to_json(self):
         return {key: value for key, value in self.__dict__.items() if not key.startswith("_")}
         
-    @classmethod
-    def _from_json(cls, json_data) -> SolisEPM:
-        base = cls()
+    def _from_json(self, json_data) -> SolisEPM:
         if json_data:
             for key, value in json_data.items():
-                if hasattr(base, key):
-                    setattr(base, key, value)
-        return base
+                if hasattr(self, key):
+                    setattr(self, key, value)
+        return self
 
 
 class SolisStations():
@@ -1462,7 +1461,7 @@ class SolisCloud():
                     has_more = False
                 epm_list = page.get('records')
                 status_vo._from_json(station_status_vo)
-                [epms.append(SolisEPM._from_json(x)) for x in epm_list]
+                [epms.append(SolisEPM(self)._from_json(x)) for x in epm_list]
                 if has_more:
                     pageNo += 1
             else:
@@ -1489,13 +1488,14 @@ class SolisCloud():
             if not success:
                 raise SolisConnectException(f"There was an error - {msg} - {res.status_code} - {res.reason}")
             data = res_json.get('data', {}) or {}
-            epm = SolisEPM._from_json(data)
+            epm = SolisEPM(self)._from_json(data)
             return epm
             
         else:
             raise SolisConnectException(f"There was an error - {res.status_code} - {res.reason}")
 
     def get_epm_data_for_day(self, sn: str, dt: date, timeZone: int, searchinfo: list[EPMFields] = [], **kwargs) -> EPMDayData:
+        default_fields = ["u_ac1","u_ac2","u_ac3","i_ac1","i_ac2","i_ac3","p_ac1","p_ac2","p_ac3","power_factor","fac_meter","p_load","e_total_inverter","e_total_load","e_total_buy","e_total_sell"]
         body = {
             "sn": sn,
             "time": dt.strftime("%Y-%m-%d"),
@@ -1505,6 +1505,10 @@ class SolisCloud():
             body.update({
                 "searchinfo": ",".join(searchinfo)
             })
+        else:
+            body.update({
+                "searchinfo": ",".join(default_fields)
+            })
         for k, v in kwargs.items():
             body.update({
                 k: v
